﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say:

    # Defaults for side_image and two_window
    default side_image = None
    default two_window = False

    # Decide if we want to use the one-window or two-window varaint.
    if not two_window:

        # The one window variant.        
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:            
                window:
                    style "say_who_window"

                    text who:
                        id "who"
                        
            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"
              
    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Use the quick menu.
    use quick_menu


##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice:

    window: 
        style "menu_window"        
        xalign 0.5
        yalign 0.5
        
        vbox:
            style "menu"
            spacing 2
            
            for caption, action, chosen in items:
                
                if action:  
                    
                    button:
                        action action
                        style "menu_choice_button"                        

                        text caption style "menu_choice"
                    
                else:
                    text caption style "menu_caption"

init -2 python:
    config.narrator_menu = True
    
    style.menu_window.set_parent(style.default)
    style.menu_choice.set_parent(style.button_text)
    style.menu_choice.clear()
    style.menu_choice_button.set_parent(style.button)
    style.menu_choice_button.xminimum = int(config.screen_width * 0.75)
    style.menu_choice_button.xmaximum = int(config.screen_width * 0.75)
         
    mr = MusicRoom(fadeout=1.0)
    mr.add("track1.ogg")


##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input:

    window:
        has vbox

        text prompt
        input id "input"

    use quick_menu

screen acerca_de:

    tag menu

    frame:        
        
        viewport id "acerca_de":             
             has vbox

             text ".heartbeats fue hecho con el motor Ren'Py para desarrollar novelas visuales en Python. \n"                          
        
             text "El juego fue enteramente desarrollado por una sola persona (yo): {b}Sebastián Trelles{/b}. Tanto la música como las imágenes y el texto fueron creados por él. Los efectos de sonido fueron tomados de videos en Internet. Y por más sencillo que parezca... FUE UN DOLOR DE CABEZA COORDINAR LOS SONIDOS CON LA MÚSICA Y LOS LATIDOS!!! Sin embargo, quedé conforme con el resultado final. Aunque no ha quedado perfecto, creo que pasa la prueba."
             
             text "\nEn cuanto al mensaje del juego, simplemente quería transmitir una historia que involucre dificultades de la vida, drama y una narrativa interesante e interactiva, centrada en emociones y decisiones. Espero que disfruten del juego tanto como he disfrutado haciéndolo.\n"
             
             text "Info de contacto:"
             text "{b}Email{/b}: strelles@gmail.com"
             text "{b}Webpage{/b}: http://theadventuregamer.blogspot.com\n"
             
             # The button that lets the user exit the music room.
             textbutton "Main Menu" action ShowMenu("main_menu")
                     
        vbar value YScrollValue("acerca_de") bar_invert True xalign 1.0    
    
screen music_room:

    tag menu

    frame:        
        
        viewport id "tips":             
             has vbox

             text "Esta es la sección de ayuda del juego.\nAquí aparecerán ayudas para avanzar en el juego a medida que desbloquees las palabras de {color=#FF0000}{b}color{/b}{/color}.\n\n"
             
             text "{color=#FF0000}{b}Funcionamiento del Juego{/b}{/color}: \nEl juego cuenta la historia de tres personas en diferentes momentos. La historia comienza en el primer evento (de Javier), sigue por el segundo evento (de Raúl) y finaliza con el tercer evento (de María)."
             
             text "\nAparte del órden cronológico, {b}los medidores de latidos se corresponden con cada uno de los personajes{/b}, e indican las {b}probabilidades de que los personajes sobrevivan o no{/b} en esa línea. Un corazón que late demasiado rápido significa que ese personaje provocará un mal a alguien. Un corazón que late demasiado lento significa que ese personaje morirá."
             
             text "\nLos sonidos también forman parte del juego. Siempre que el latido de un corazón esté acompañado de su sonido, significa que la persona está presente en la escena.\n\n"
             
             
             text "{color=#FFFF00}{b}Básica Javier{/b}{/color}: Javier es un chico joven con el problema que es diferente. Debes animarlo para que busque ayuda y no cometa un grave error.\n"
        
             text "{color=#0000FF}{b}Básica Raúl{/b}{/color}: Raúl es un joven adulto, que cuando bebe, pierde noción de sus valores y afectos. Debes ayudarlo para que recupere su relación con su novia.\n"
        
             text "{color=#FF0000}{b}Básica María{/b}{/color}: María es una mujer adulta que ha perdido temporalmente la memoria al sufrir un desmayo en su casa. Ayudala a recuperarla y luchar contra lo que viene.\n"
            
             $epilogo=False
             for texto in persistent.key_words:
                 
                 if texto=="consejo":
                     text ("{color=#FFFF00}Consejo{/color}: Javier ha mencionado que cree dar buenos consejos. Si surge la oportunidad, quizás sea buena idea pedir su opinión en algún tema.\n")
                 elif texto=="hermano":
                     text ("{color=#FFFF00}Hermano{/color}: Javier dijo tener un hermano, con el cual perdió contacto.\n")
                 elif texto=="madurar":
                     text ("{color=#FFFF00}Madurar{/color}: Javier ha dicho que le gustaría madurar. ¿Lo logrará en algún camino?\n")
                 elif texto=="direccionContraria":
                     text ("{color=#FFFF00}Dirección Contraria{/color}: Javier dijo que siente que avanza en dirección contraria al resto del mundo. Hmmm...\n")
                 elif texto=="medicina":
                     text ("{color=#FFFF00}Medicina{/color}: Javier ha mencionado que le gustaría estudiar medicina de grande. Curioso... dado que uno de los personajes del juego es médico.\n")
                 elif texto=="diferente":
                     text ("{color=#FFFF00}Ser diferente{/color}: Javier cree que es diferente al resto de la gente. Hmmm...\n")
                     
                 elif texto=="recuperarla":
                     text ("{color=#0000FF}Recuperarla{/color}: Raúl está decidido a recuperar a María. Y para ello, ha pedido ayuda a Javier. ¿Podrán cumplir lo que desean?\n")
                 elif texto=="viaje":
                     text ("{color=#0000FF}Viaje{/color}: Raúl dice haber ido de viaje con María a un pueblo lejano, y este recuerdo parece ser muy importante para ambos. Será mejor apuntarlo...\n")
                 elif texto=="error":
                     text ("{color=#0000FF}Error{/color}: Raúl dice haber cometido un grave error en su noviazgo con María. Ahora que lo ha reconocido, las cosas serán más fáciles.\n")
                 elif texto=="perdida":
                     text ("{color=#0000FF}Perdida{/color}: Si Raúl se desespera en recuperar a María de inmediato, la perderá totalmente. A veces, puede ser bueno esperar...\n")
                 elif texto=="equivocado":
                     text ("{color=#0000FF}Equivocado{/color}: La mujer del tercer evento cree estar casada. ¿Quizás esto se conecta con alguno de los demás eventos del juego?\n")
                 elif texto=="aprenderDeSusErrores":
                     text ("{color=#0000FF}Parque{/color}: María y Raúl vinieron a este parque el primer día que se conocieron. Guarda un especial significado para ambos.\n")
                     text ("{color=#0000FF}Aprender de sus errores{/color}: Es lo que pide Raúl de María, que le de una oportunidad de aprender de sus errores.\n")
                     
                 elif texto=="profesora":
                     text ("{color=#FF0000}Profesora{/color}: María dice ser profesora de ciencias sociales. Ha ido a la Universidad de Letras, y luego, comenzó a dar clases.\n")                     
                 elif texto=="marido":
                     text ("{color=#FF0000}Marido{/color}: María cree estar casada. ¿Quizás esto se conecta con alguno de los demás eventos del juego?\n")
                 elif texto=="sinMedicamentos":
                     text ("{color=#FF0000}Sin Medicamentos{/color}: María no quiso ingerir medicamentos, a pesar de sentirse mal. Quizás por lo que sucedería luego...\n")
                     
                 elif texto=="perdonado":
                     text ("{color=#FF0000}Segunda Oportunidad{/color}: María le dio a Raúl una segunda oportunidad. Y esto... cambió la vida de Raúl radicalmente.\n")    
                     
                 elif texto=="epilogue":
                     $epilogo=True    
                     

             if epilogo:
                  text ("{color=#FF0000}{b}Epílogo{/b}{/color}: Un día de campo. Javier, junto con María, Raúl y la hija de ambos disfrutando de la vida. Este es el mejor final del juego. Y el mensaje máximo que el juego quiere transmitir. Felicidades.\n")
                  
             # The button that lets the user exit the music room.
             textbutton "Main Menu" action ShowMenu("main_menu")
                     
        vbar value YScrollValue("tips") bar_invert True xalign 1.0
    
##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl:

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0
    
    use quick_menu
        
##############################################################################
# Main Menu 
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu:
    tag menu

    if persistent.endings_unlocked == True:
        use main_menu_special    
    else:
        use main_menu_default

screen main_menu_default:

    # The background of the main menu.
    window:
        style "mm_root"

    # The main menu buttons.
    frame:
        style_group "mm"
        xalign .98
        yalign .98

        has vbox

        textbutton _("Start Game") action Start()                
        textbutton _("Preferences") action ShowMenu("preferences")
        textbutton _("About") action ShowMenu("acerca_de")
        textbutton _("Quit") action Quit(confirm=False)
        
screen main_menu_special:

    # The background of the main menu.
    window:
        style "mm_root"

    # The main menu buttons.
    frame:
        style_group "mm"
        xalign .98
        yalign .98

        has vbox

        textbutton _("Start Game") action Start()
        textbutton _("Tips") action ShowMenu("music_room") #ShowMenu("tips")        
        textbutton _("About") action ShowMenu("acerca_de")
        textbutton _("Quit") action Quit(confirm=False)        

init -2 python:

    # Make all the main menu buttons be the same size.
    style.mm_button.size_group = "mm"


##############################################################################
# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation:

    # The background of the game menu.
    window:
        style "gm_root"

    # The various buttons.
    frame:
        style_group "gm_nav"
        xalign .98
        yalign .98
        
        has vbox

        textbutton _("Return") action Return()        
        textbutton _("Quit") action Quit()

init -2 python:
    style.gm_nav_button.size_group = "gm_nav"
    

##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.
    
screen file_picker:

    frame:
        style "file_picker_frame"

        has vbox

        # The buttons at the top allow the user to pick a
        # page of files.
        hbox:
            style_group "file_picker_nav"
            
            textbutton _("Previous"):
                action FilePagePrevious()

            textbutton _("Auto"):
                action FilePage("auto")

            textbutton _("Quick"):
                action FilePage("quick")

            for i in range(1, 9):
                textbutton str(i):
                    action FilePage(i)
                    
            textbutton _("Next"):
                action FilePageNext()

        $ columns = 2
        $ rows = 5
                
        # Display a grid of file slots.
        grid columns rows:
            transpose True
            xfill True
            style_group "file_picker"
            
            # Display ten file slots, numbered 1 - 10.
            for i in range(1, columns * rows + 1):

                # Each file slot is a button.
                button:
                    action FileAction(i)
                    xfill True

                    has hbox

                    # Add the screenshot.
                    add FileScreenshot(i)
                    
                    # Format the description, and add it as text.
                    $ description = "% 2s. %s\n%s" % (
                        FileSlotName(i, columns * rows),
                        FileTime(i, empty=_("Empty Slot.")),
                        FileSaveName(i))

                    text description

                    key "save_delete" action FileDelete(i)
                    
                    
screen save:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

screen load:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

init -2 python:
    style.file_picker_frame = Style(style.menu_frame)

    style.file_picker_nav_button = Style(style.small_button)
    style.file_picker_nav_button_text = Style(style.small_button_text)

    style.file_picker_button = Style(style.large_button)
    style.file_picker_text = Style(style.large_button_text)

    

##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces

screen preferences:

    tag menu

    # Include the navigation.
    use navigation

    # Put the navigation columns in a three-wide grid.
    grid 3 1:
        style_group "prefs"
        xfill True

        # The left column.
        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Display")
                textbutton _("Window") action Preference("display", "window")
                textbutton _("Fullscreen") action Preference("display", "fullscreen")

            frame:
                style_group "pref"
                has vbox

                label _("Transitions")
                textbutton _("All") action Preference("transitions", "all")
                textbutton _("None") action Preference("transitions", "none")

            frame:
                style_group "pref"
                has vbox

                label _("Text Speed")
                bar value Preference("text speed")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Joystick...") action Preference("joystick")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Skip")
                textbutton _("Seen Messages") action Preference("skip", "seen")
                textbutton _("All Messages") action Preference("skip", "all")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Begin Skipping") action Skip()

            frame:
                style_group "pref"
                has vbox

                label _("After Choices")
                textbutton _("Stop Skipping") action Preference("after choices", "stop")
                textbutton _("Keep Skipping") action Preference("after choices", "skip")

            frame:
                style_group "pref"
                has vbox

                label _("Auto-Forward Time")
                bar value Preference("auto-forward time")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Music Volume")
                bar value Preference("music volume")

            frame:
                style_group "pref"
                has vbox

                label _("Sound Volume")
                bar value Preference("sound volume")

                if config.sample_sound:
                    textbutton "Test":
                        action Play("sound", config.sample_sound)
                        style "soundtest_button"

            frame:
                style_group "pref"
                has vbox

                label _("Voice Volume")
                bar value Preference("voice volume")

                if config.sample_voice:
                    textbutton "Test":
                        action Play("voice", config.sample_voice)
                        style "soundtest_button"

screen tips:    
    tag menu

    # Include the navigation.
    use navigation

    # Put the navigation columns in a three-wide grid.
    grid 3 1:
        style_group "prefs"
        xfill True

        # The left column.
        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Display")
                textbutton _("Window") action Preference("display", "window")
                textbutton _("Fullscreen") action Preference("display", "fullscreen")

            frame:
                style_group "pref"
                has vbox

                label _("Transitions")
                textbutton _("All") action Preference("transitions", "all")
                textbutton _("None") action Preference("transitions", "none")

            frame:
                style_group "pref"
                has vbox

                label _("Text Speed")
                bar value Preference("text speed")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Joystick...") action Preference("joystick")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Skip")
                textbutton _("Seen Messages") action Preference("skip", "seen")
                textbutton _("All Messages") action Preference("skip", "all")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Begin Skipping") action Skip()

            frame:
                style_group "pref"
                has vbox

                label _("After Choices")
                textbutton _("Stop Skipping") action Preference("after choices", "stop")
                textbutton _("Keep Skipping") action Preference("after choices", "skip")

            frame:
                style_group "pref"
                has vbox

                label _("Auto-Forward Time")
                bar value Preference("auto-forward time")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Music Volume")
                bar value Preference("music volume")

            frame:
                style_group "pref"
                has vbox

                label _("Sound Volume")
                bar value Preference("sound volume")

                if config.sample_sound:
                    textbutton "Test":
                        action Play("sound", config.sample_sound)
                        style "soundtest_button"

            frame:
                style_group "pref"
                has vbox

                label _("Voice Volume")
                bar value Preference("voice volume")

                if config.sample_voice:
                    textbutton "Test":
                        action Play("voice", config.sample_voice)
                        style "soundtest_button"             
                        
init -2 python:
    style.pref_frame.xfill = True
    style.pref_frame.xmargin = 5
    style.pref_frame.top_margin = 5

    style.pref_vbox.xfill = True

    style.pref_button.size_group = "pref"
    style.pref_button.xalign = 1.0

    style.pref_slider.xmaximum = 192
    style.pref_slider.xalign = 1.0

    style.soundtest_button.xalign = 1.0


##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt
    
screen yesno_prompt:

    modal True

    window:
        style "gm_root"

    frame:
        style_group "yesno"

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05
        
        has vbox:
            xalign .5
            yalign .5
            spacing 30
            
        label _(message):
            xalign 0.5

        hbox:
            xalign 0.5
            spacing 100
            
            textbutton _("Yes") action yes_action
            textbutton _("No") action no_action


init -2 python:    
    style.yesno_button.size_group = "yesno"
    style.yesno_label_text.text_align = 0.5


##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu:

    # Add an in-game quick menu.
    hbox:
        style_group "quick"
    
        xalign 1.0
        yalign 1.0
        
        textbutton _("Auto") action Preference("auto-forward", "toggle")
        textbutton _("Main Menu") action MainMenu(confirm=True)
        textbutton _("Quit") action Quit(confirm=True)
        
init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None
    style.quick_button.xpadding = 5

    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 12
    style.quick_button_text.idle_color = "#8888"
    style.quick_button_text.hover_color = "#ccc"
    style.quick_button_text.selected_idle_color = "#cc08"
    style.quick_button_text.selected_hover_color = "#cc0"
    style.quick_button_text.insensitive_color = "#4448"
    
    # Set a default value for the auto-forward time, and note that AFM is
    # turned off by default.
    config.default_afm_time = 10
    config.default_afm_enable = False
    
    